@@ -6,8 +6,20 @@ describe Dotenv do
       let(:env_files) { [] }
 
       it 'defaults to .env' do
-        Dotenv::Environment.should_receive(:new).with('.env').
-          and_return(mock(:apply => {}))
+        Dotenv::Environment.should_receive(:new).with(expand('.env')).
+          and_return(double(:apply => {}))
+        subject
+      end
+    end
+
+    context 'with a tilde path' do
+      let(:env_files) { ['~/.env'] }
+
+      it 'expands the path' do
+        expected = expand("~/.env")
+        File.stub(:exists?){ |arg| arg == expected }
+        Dotenv::Environment.should_receive(:new).with(expected).
+          and_return(double(:apply => {}))
         subject
       end
     end
@@ -16,7 +28,12 @@ describe Dotenv do
       let(:env_files) { ['.env', fixture_path('plain.env')] }
 
       let(:expected) do
-        {'OPTION_A' => '1', 'OPTION_B' => '2', 'DOTENV' => 'true'}
+        { 'OPTION_A' => '1',
+          'OPTION_B' => '2',
+          'OPTION_C' => '3',
+          'OPTION_D' => '4',
+          'OPTION_E' => '5',
+          'DOTENV' => 'true' }
       end
 
       it 'loads all files' do
@@ -68,4 +85,8 @@ describe Dotenv do
   def fixture_path(name)
     File.join(File.expand_path('../fixtures', __FILE__), name)
   end
+
+  def expand(path)
+    File.expand_path path
+  end
 end
